package org.jeecg.modules.app.controller;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.app.service.IOrderService;
import org.jeecg.modules.app.vo.OrderVO;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

@Slf4j
@Tag(name = "APP订单相关接口")
@RestController
@RequestMapping("/app/order")
public class OrderController {
    @Resource
    private IOrderService appOrderService;
    /**
     * @Author SheepHy
     * @Description 学校场地预约-预览页
     * @Date 10:10 2025/7/14
     * @Param placeId startTime
     * @return Result<OrderVO.PreviewOrderPlaceSchool>
     **/
    @Operation(summary="学校场地预约-预览页")
    @GetMapping("/previewOrderPlaceSchool")
    public Result<OrderVO.PreviewOrderPlaceSchool> previewOrderPlaceSchool(@RequestParam("placeId") @Schema(description = "场地ID")String placeId,
                                                                           @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
                                                                           @DateTimeFormat(pattern = "yyyy-MM-dd")
                                                                           @RequestParam("startTime") @Schema(description = "当前选择日期（年月日）")Date startTime){
        return Result.ok(appOrderService.previewOrderPlaceSchool(placeId,startTime));
    }

    /**
     * @Author SheepHy
     * @Description 课程限购校验
     * @Date 16:22 2025/7/14
     * @Param courseId 课程ID
     * @return boolean
     **/
    @Operation(summary="课程限购校验")
    @GetMapping("/checkCourseLimitNum")
    public Result<Boolean> checkCourseLimitNum(@RequestParam("courseId") @Schema(description = "课程ID")String courseId,
                                               @RequestParam("limitNum") @Schema(description = "购买数")int limitNum){
        return Result.OK(appOrderService.checkCourseLimitNum(courseId, limitNum));
    }

    /**
     * @Author SheepHy
     * @Description 课程购买-预览页（学校课程、体育馆课程、教练课程）
     * @Date 15:43 2025/7/14
     * @Param courseId
     * @return OrderVO.PreviewOrderCourseSchool {@link OrderVO.PreviewOrderCourse}
     **/
    @Operation(summary="课程购买-预览页（学校课程、体育馆课程、教练课程）")
    @GetMapping("/previewOrderCourse")
    public Result<OrderVO.PreviewOrderCourse> previewOrderCourse(@RequestParam("courseId") @Schema(description = "课程ID")String courseId){
        return Result.ok(appOrderService.previewOrderCourse(courseId));
    }

    /**
     * @Author SheepHy
     * @Description 体育馆包场-预览页
     * @Date 16:13 2025/7/14
     * @Param placeId
     * @return OrderVO.PreviewOrderPlaceGymnasiumChartered {@link OrderVO.PreviewOrderPlaceGymnasiumChartered}
     **/
    @Operation(summary="体育馆包场-预览页")
    @GetMapping("/previewOrderPlaceGymnasiumChartered")
    public Result<OrderVO.PreviewOrderPlaceGymnasiumChartered> previewOrderPlaceGymnasiumChartered(@RequestParam("rulesId") @Schema(description = "场次IDS多个逗号拼接")String rulesId){
        return Result.ok(appOrderService.previewOrderPlaceGymnasiumChartered(rulesId));
    }

    /**
     * @Author SheepHy
     * @Description 学校场地预约-创建
     * @Date 10:10 2025/7/14
     * @Param rulesId 时间段ID
     * @return OrderVO.createOrderPlaceSchool
     **/
    @Operation(summary="学校场地预约-创建")
    @GetMapping("/createOrderPlaceSchool")
    public Result<OrderVO.createOrderPlaceSchool> createOrderPlaceSchool(@RequestParam("rulesId") @Schema(description = "场次IDS多个逗号拼接")String rulesId,
                                                                         @RequestParam("userIds") @Schema(description = "使用用户IDS多个逗号拼接")String userIds){
        return Result.ok(appOrderService.createOrderPlaceSchool(rulesId, userIds));
    }

    /**
     * @Author SheepHy
     * @Description 学校包场-预览时间选择
     * @Date 14:45 2025/7/17
     * @Param placeId
     * @return OrderVO.PreviewOrderPlaceSchoolTime {@link OrderVO.PreviewOrderPlaceSchoolTime}
     **/
    @Operation(summary="学校包场-预览时间选择")
    @GetMapping("/previewOrderPlaceSchoolTime")
    public Result<List<OrderVO.PreviewOrderPlaceSchoolTime>> previewOrderPlaceSchoolTime(@RequestParam("placeId") @Schema(description = "当前选择场次ID")String placeId){
        return Result.ok(appOrderService.previewOrderPlaceSchoolTime(placeId));
    }
}
