package org.jeecg.modules.app.service.impl;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.log4j.Log4j2;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.app.service.IOrderService;
import org.jeecg.modules.app.vo.OrderVO;
import org.jeecg.modules.system.app.entity.*;
import org.jeecg.modules.system.app.mapper.*;
import org.jeecg.modules.system.entity.SysDepart;
import org.jeecg.modules.system.mapper.SysDepartMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.concurrent.ThreadLocalRandom;

@Service
@Log4j2
public class OrderServiceImpl implements IOrderService {
    @Resource
    private AppSitePlaceMapper appSitePlaceMapper;
    @Resource
    private AppSitePriceRulesMapper appSitePriceRulesMapper;
    @Resource
    private AppCoursesMapper appCoursesMapper;
    @Resource
    private AppOrderMapper appOrderMapper;
    @Resource
    private SysDepartMapper sysDepartMapper;
    @Resource
    private AppOrderProductMapper appOrderProductMapper;
    @Resource
    private AppSiteMapper appSiteMapper;
    @Resource
    private AppIsinMapper appIsinMapper;
    @Resource
    private FamilyMembersMapper familyMembersMapper;
    @Resource
    private AppTeachingTimeMapper appTeachingTimeMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public OrderVO.createOrderPlaceSchool createOrderPlaceSchool(String rulesId, String userIds) {
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> list = Arrays.asList(rulesId.split(","));
        AppOrder order = createOrder(list, 0, user.getId(), userIds);
        if(null == order) throw new JeecgBootException("创建订单失败!");
        AppSitePriceRules appSitePriceRules = appSitePriceRulesMapper.selectById(list.get(0));
        AppSitePlace appSitePlace = appSitePlaceMapper.selectById(appSitePriceRules.getSitePlaceId());
        AppSite appSite = appSiteMapper.selectById(appSitePlace.getSiteId());
        OrderVO.createOrderPlaceSchool result = new OrderVO.createOrderPlaceSchool();
        List<OrderVO.couponNumberInformation> couponNumberInformation = new ArrayList<>();
        List<AppIsin> appIsins = appIsinMapper.selectList(Wrappers.<AppIsin>lambdaQuery().eq(AppIsin::getOrderId, order.getId()));
        appIsins.forEach(appIsin -> {
            OrderVO.couponNumberInformation information = new OrderVO.couponNumberInformation();
            information.setId(appIsin.getId())
                    .setCouponCode(appIsin.getIsinCode())
                    .setCouponStatus(appIsin.getIsinStatus())
                    .setExpireTime(appIsin.getExpireTime())
                    .setUserName(familyMembersMapper.selectById(appIsin.getFamilyId()).getFullName());
            couponNumberInformation.add(information);
        });
        result.setId(order.getId())
                .setOrderStatus(order.getOrderStatus())
                .setPlaceName(appSitePlace.getName())
                .setDate(appSitePriceRules.getDateOfSale())
                .setUserName(user.getRealname())
                .setAddress(appSite.getAddress())
                .setLongitude(appSite.getLongitude())
                .setLatitude(appSite.getLatitude())
                .setReminder(appSitePlace.getReminder())
                .setOrderCode(order.getOrderCode())
                .setMobile(user.getPhone())
                .setCreateTime(order.getCreateTime())
                .setPayTime(order.getPayTime())
                .setCouponNumberInformation(couponNumberInformation);
        return result;
    }

    @Override
    public boolean checkCourseLimitNum(String courseId, int limitNum) {
        return appCoursesMapper.selectById(courseId).getLimitNum() >= limitNum;
    }

    @Override
    public OrderVO.PreviewOrderPlaceSchool previewOrderPlaceSchool(String placeId, Date startTime) {
        LocalDate localDate = startTime.toInstant().atZone(ZoneId.systemDefault()).toLocalDate();
        Date dateOnly = Date.from(localDate.atStartOfDay(ZoneId.systemDefault()).toInstant());
        OrderVO.PreviewOrderPlaceSchool previewOrderPlaceSchool = new OrderVO.PreviewOrderPlaceSchool();
        List<OrderVO.PreviewOrderPlaceSchoolChild> timeSlot = appSitePriceRulesMapper.timeSlot(placeId, dateOnly);
        AppSitePlace appSitePlace = appSitePlaceMapper.selectById(placeId);
        previewOrderPlaceSchool.setName(appSitePlace.getName())
                .setId(appSitePlace.getId())
                .setTimeSlot(timeSlot);
        return previewOrderPlaceSchool;
    }

    @Override
    public OrderVO.PreviewOrderCourse previewOrderCourse(String courseId) {
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        OrderVO.PreviewOrderCourse previousOrderCourse = new OrderVO.PreviewOrderCourse();
        AppCourses appCourses = appCoursesMapper.selectById(courseId);
        List<String> list = Arrays.asList(appCourses.getCover().split(","));
        boolean checkCourseDiscount = checkCourseDiscount(appCourses.getCategoryId(), user.getId());
        previousOrderCourse.setId(appCourses.getId())
                .setCover(list.get(0))
                .setName(appCourses.getName())
                .setSellingPrice(appCourses.getSellingPrice())
                .setReminder(appCourses.getReminder())
                .setHasDiscount(checkCourseDiscount);
        if(checkCourseDiscount){
            previousOrderCourse.setDiscountPrice(appCourses.getSellingPrice());
            previousOrderCourse.setTotalDiscount(appCourses.getSellingPrice());
            previousOrderCourse.setSubtotal(appCourses.getSellingPrice().subtract(appCourses.getSellingPrice()));
            previousOrderCourse.setTotalPrice(appCourses.getSellingPrice().subtract(appCourses.getSellingPrice()));
        }else {
            previousOrderCourse.setDiscountPrice(BigDecimal.ZERO);
            previousOrderCourse.setTotalDiscount(BigDecimal.ZERO);
            previousOrderCourse.setSubtotal(appCourses.getSellingPrice());
            previousOrderCourse.setTotalPrice(appCourses.getSellingPrice());
        }
        return previousOrderCourse;
    }

    @Override
    public OrderVO.PreviewOrderPlaceGymnasiumChartered previewOrderPlaceGymnasiumChartered(String rulesId) {
        List<String> list = Arrays.asList(rulesId.split(","));
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        OrderVO.PreviewOrderPlaceGymnasiumChartered result = new OrderVO.PreviewOrderPlaceGymnasiumChartered();
        List<AppSitePriceRules> priceRules = new ArrayList<>();
        list.forEach(priceRule -> {
            AppSitePriceRules appSitePriceRule = appSitePriceRulesMapper.selectById(priceRule);
            priceRules.add(appSitePriceRule);
        });
        BigDecimal totalPrice = priceRules.stream()
                .map(AppSitePriceRules::getSellingPrice)
                .reduce(BigDecimal.ZERO, BigDecimal::add);
        // 格式化 totalPrice 和 subtotal 为两位小数
        totalPrice = totalPrice.setScale(2, BigDecimal.ROUND_HALF_UP);
        String formattedTotalPrice = totalPrice.toString(); // 直接使用 toString() 保留两位小数
        String formattedSubtotal = totalPrice.toString();   // 小计与总价相同
        result.setTotalPrice(new BigDecimal(formattedTotalPrice)); // 设置格式化后的 totalPrice
        result.setSubtotal(new BigDecimal(formattedSubtotal));
        if (priceRules.isEmpty()) {
            throw new IllegalArgumentException("未找到对应的价格规则");
        }
        AppSitePlace sitePlace = appSitePlaceMapper.selectById(priceRules.get(0).getSitePlaceId());
        if (sitePlace == null) {
            throw new IllegalStateException("关联场地不存在");
        }
        List<OrderVO.PreviewOrderTimePeriod> timePeriod = appSitePriceRulesMapper.previewOrderPlaceGymnasiumChartered(list);
        SysDepart depart = sysDepartMapper.selectOne(Wrappers.<SysDepart>lambdaQuery()
                .eq(SysDepart::getOrgCode, sitePlace.getOrgCode()));
        return result.setTimePeriod(timePeriod)
                .setEarlyRefundTime(sitePlace.getEarlyRefundTime())
                .setPlaceId(sitePlace.getId())
                .setPlaceName(sitePlace.getName())
                .setReminder(sitePlace.getReminder())
                .setRefundRule(sitePlace.getEarlyRefundTime())
                .setMobile(user.getPhone())
                .setTotalPrice(totalPrice)  // 总价即为所有价格之和
                .setSubtotal(totalPrice)    // 小计与总价相同
                .setStoreName(depart != null ? depart.getDepartName() : "未知门店");
    }

    @Override
    public List<OrderVO.PreviewOrderPlaceSchoolTime> previewOrderPlaceSchoolTime(String placeId) {
        return appTeachingTimeMapper.previewOrderPlaceSchoolTime(appSitePlaceMapper.selectById(placeId).getOrgCode());
    }

    /**
     * @Author SheepHy
     * @Description 查询用户对该类型课程是否有试听资格
     * @Date 16:45 2025/7/14
     * @Param courseId userId
     * @return boolean
     **/
    private boolean checkCourseDiscount(String categoryId, String userId) {
        boolean success = Boolean.TRUE;
        List<AppOrder> appOrders = appOrderMapper.selectList(Wrappers.<AppOrder>lambdaQuery()
                .eq(AppOrder::getUserId, userId)
                .ne(AppOrder::getOrderStatus, 6)
                .ne(AppOrder::getOrderStatus, 5)
                .eq(AppOrder::getStatus, 0)
                .eq(AppOrder::getDelFlag, 0)
                .eq(AppOrder::getType,2));
        if (appOrders.isEmpty()) return true;
        for (AppOrder appOrder : appOrders) {
            if (!appOrder.getProductIds().contains(categoryId)) {
                success = false;
                break;
            }
        }
        return success;
    }

    /**
     * @Author SheepHy
     * @Description 根据不同的类型生成订单及订单明细
     * @Date 15:09 2025/7/15
     * @Param id type userId
     * @return
     **/
    @Transactional
    public AppOrder createOrder(List<String> id, int type, String userId, String userIds) {
        //todo 保险 闸机待接入
        //订单类型；0场地1赛事2课程
        AppOrder appOrder = new AppOrder();
        switch(type){
            case 0:
                List<AppSitePriceRules> priceRules = appSitePriceRulesMapper.selectList(Wrappers.<AppSitePriceRules>lambdaQuery()
                        .in(AppSitePriceRules::getId, id));
                BigDecimal totalPrice = priceRules.stream()
                        .map(AppSitePriceRules::getSellingPrice)
                        .reduce(BigDecimal.ZERO, BigDecimal::add);
                if(priceRules.get(0).getType() == 0){
                    if(totalPrice.compareTo(BigDecimal.ZERO) == 0){
                        appOrder.setPayType(3)
                                .setOrderStatus(2)
                                .setPayTime(new Date());
                    }else {
                        appOrder.setPayType(2)
                                .setOrderStatus(1);
                    }
                    String s = generateOrderNumber(0);
                    appOrder.setOrderCode(s)
                            .setOrderCode(priceRules.get(0).getOrgCode())
                            .setProductIds(priceRules.get(0).getSitePlaceId())
                            .setType(0)
                            .setUserId(userId)
                            .setOriginalPrice(totalPrice)
                            .setPrice(totalPrice)
                            .setCreateTime(new Date())
                            .setUpdateTime(new Date())
                            .setCreateBy(userId)
                            .setUpdateBy(userId);
                    createOrderCoupon(s, userIds);
                    appOrderMapper.insert(appOrder);
                    createOrderProduct(appOrder, id);
                }
                break;
            case 1:
                break;
            case 2:

                break;
        }
        return appOrder;
    }

    /**
     * @Author SheepHy
     * @Description 订单编号生成逻辑
     * @Date 17:18 2025/7/15
     * @return String 订单号
     **/
    private String generateOrderNumber(int type) {
        String format = DateUtil.format(new Date(), "yyyyMMddHHmmss");
        int nextInt = ThreadLocalRandom.current().nextInt(1000, 10000);
        if(type == 0){
            return "D" + format + nextInt;
        }else {
            return "T" + format + nextInt;
        }
    }

    /**
     * @Author SheepHy
     * @Description 根据订单及购买人数生成对应券码
     * @Date 10:20 2025/7/16
     * @Param
     * @return
     **/
    private void createOrderCoupon(String orderId, String userIds) {
        String lastFourDigits = orderId.substring(orderId.length() - 4);
        int nextInt = ThreadLocalRandom.current().nextInt(1000, 10000);
        Arrays.asList(userIds.split(",")).forEach(userId -> {
            String substring = userId.substring(orderId.length() - 2);
            AppIsin appIsin = new AppIsin();
            appIsin.setOrderId(orderId)
                    .setFamilyId(userId)
                    .setIsinCode(lastFourDigits + nextInt + substring)
                    .setIsinStatus(1)
                    .setCreateTime(new Date())
                    .setUpdateTime(new Date());
        });
    }

    /**
     * @Author SheepHy
     * @Description 生成订单明细
     * @Date 11:57 2025/7/16
     * @Param appOrder id
     **/
    private void createOrderProduct(AppOrder appOrder, List<String> id){
        id.forEach(productId -> {
            AppOrderProduct appOrderProduct = new AppOrderProduct();
            appOrderProduct.setOrderId(appOrder.getId())
                    .setProductId(appOrder.getProductIds())
                    .setRuleId(productId)
                    .setCreateBy(appOrder.getCreateBy())
                    .setUpdateBy(appOrder.getUpdateBy())
                    .setCreateTime(new Date())
                    .setUpdateTime(new Date());
            appOrderProductMapper.insert(appOrderProduct);
        });
    }
}
