package org.jeecg.modules.system.app.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.system.app.entity.AppBanner;
import org.jeecg.modules.system.app.service.IAppBannerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

/**
 * @Description: 首页轮播图管理
 * @Author: jeecg-boot
 * @Date:   2023-08-14
 * @Version: V1.0
 */
@Tag(name="首页轮播图管理")
@RestController
@RequestMapping("/app/appBanner")
@Slf4j
public class AppBannerController extends JeecgController<AppBanner, IAppBannerService> {
	@Autowired
	private IAppBannerService appBannerService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appBanner
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "首页轮播图管理-分页列表查询")
	@Operation(summary="首页轮播图管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppBanner>> queryPageList(AppBanner appBanner,
													@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													HttpServletRequest req) {
		QueryWrapper<AppBanner> queryWrapper = QueryGenerator.initQueryWrapper(appBanner, req.getParameterMap());
		Page<AppBanner> page = new Page<AppBanner>(pageNo, pageSize);
		IPage<AppBanner> pageList = appBannerService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param appBanner
	 * @return
	 */
	@AutoLog(value = "首页轮播图管理-添加")
	@Operation(summary="首页轮播图管理-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppBanner appBanner) {
		appBanner.setDelFlag(CommonConstant.DEL_FLAG_0);
		appBannerService.save(appBanner);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appBanner
	 * @return
	 */
	@AutoLog(value = "首页轮播图管理-编辑")
	@Operation(summary="首页轮播图管理-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppBanner appBanner) {
		appBannerService.updateById(appBanner);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "首页轮播图管理-通过id删除")
	@Operation(summary="首页轮播图管理-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appBannerService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "首页轮播图管理-批量删除")
	@Operation(summary="首页轮播图管理-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.appBannerService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "首页轮播图管理-通过id查询")
	@Operation(summary="首页轮播图管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppBanner> queryById(@RequestParam(name="id",required=true) String id) {
		AppBanner appBanner = appBannerService.getById(id);
		if(appBanner==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(appBanner);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appBanner
    */
    @RequiresPermissions("app:app_banner:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppBanner appBanner) {
        return super.exportXls(request, appBanner, AppBanner.class, "首页轮播图管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("app:app_banner:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppBanner.class);
    }
}
