package org.jeecg.modules.system.app.controller;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.system.app.dto.AppCoursesCuDTO;
import org.jeecg.modules.system.app.dto.AppCoursesDTO;
import org.jeecg.modules.system.app.dto.AppCoursesPageDTO;
import org.jeecg.modules.system.app.entity.AppCourses;
import org.jeecg.modules.system.app.service.IAppCoureseService;

import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
 /**
 * @Description: 课程/培训表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Tag(name="课程/培训表")
@RestController
@RequestMapping("/app/appCourese")
@Slf4j
public class AppCoursesController extends JeecgController<AppCourses, IAppCoureseService> {
	@Autowired
	private IAppCoureseService appCoursesService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dto
	 * @return
	 */
	//@AutoLog(value = "课程/培训表-分页列表查询")
	@Operation(summary="课程/培训表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppCoursesCuDTO>> queryPageList(AppCoursesPageDTO dto) {
		return Result.OK(appCoursesService.queryWitchPriceRulesPage(dto));
	}
	
	/**
	 *   添加
	 *
	 * @param appCoursesDTO
	 * @return
	 */
	@AutoLog(value = "课程/培训表-添加")
	@Operation(summary="课程/培训表-添加")
//	@RequiresPermissions("org.jeecg.modules.app:nm_courese:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppCoursesDTO appCoursesDTO) {
		return appCoursesService.saveWitchPriceRules(appCoursesDTO)?Result.OK("添加成功！"):Result.error("添加失败！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appCoursesDTO
	 * @return
	 */
	@AutoLog(value = "课程/培训表-编辑")
	@Operation(summary="课程/培训表-编辑")
//	@RequiresPermissions("org.jeecg.modules.app:nm_courese:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppCoursesCuDTO appCoursesDTO) {
		return appCoursesService.editWitchPriceRules(appCoursesDTO)?Result.OK("操作成功！"):Result.error("操作失败！");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "课程/培训表-通过id删除")
	@Operation(summary="课程/培训表-通过id删除")
//	@RequiresPermissions("org.jeecg.modules.app:nm_courese:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		return appCoursesService.deleteWitchPriceRulesById(id)?Result.OK("操作成功！"):Result.error("操作失败！");
	}
	
//	/**
//	 *  批量删除
//	 *
//	 * @param ids
//	 * @return
//	 */
//	@AutoLog(value = "课程/培训表-批量删除")
//	@Operation(summary="课程/培训表-批量删除")
//	@RequiresPermissions("org.jeecg.modules.app:nm_courese:deleteBatch")
//	@DeleteMapping(value = "/deleteBatch")
//	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
//		this.appCoursesService.removeByIds(Arrays.asList(ids.split(",")));
//		return Result.OK("批量删除成功!");
//	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "课程/培训表-通过id查询")
	@Operation(summary="课程/培训表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppCoursesDTO> queryById(@RequestParam(name="id",required=true) String id) {
		return Result.OK(appCoursesService.queryWitchPriceRulesById(id));
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appCourese
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_courese:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppCourses appCourese) {
        return super.exportXls(request, appCourese, AppCourses.class, "课程/培训表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_courese:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppCourses.class);
    }

}
