package org.jeecg.modules.system.app.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.system.app.entity.AppSitePriceRules;
import org.jeecg.modules.system.app.service.IAppSitePriceRulesService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
 /**
 * @Description: 场地价格规则表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Tag(name="场地明细规则表")
@RestController
@RequestMapping("/app/appSitePriceRules")
@Slf4j
public class AppSitePriceRulesController extends JeecgController<AppSitePriceRules, IAppSitePriceRulesService> {
	@Autowired
	private IAppSitePriceRulesService appSitePriceRulesService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appSitePriceRules
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "场地价格规则表-分页列表查询")
	@Operation(summary="场地价格规则表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppSitePriceRules>> queryPageList(AppSitePriceRules appSitePriceRules,
														  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
														  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
														  HttpServletRequest req) {


        QueryWrapper<AppSitePriceRules> queryWrapper = QueryGenerator.initQueryWrapper(appSitePriceRules, req.getParameterMap());
		Page<AppSitePriceRules> page = new Page<AppSitePriceRules>(pageNo, pageSize);
		IPage<AppSitePriceRules> pageList = appSitePriceRulesService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param appSitePriceRules
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-添加")
	@Operation(summary="场地价格规则表-添加")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppSitePriceRules appSitePriceRules) {
		appSitePriceRulesService.save(appSitePriceRules);

		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appSitePriceRules
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-编辑")
	@Operation(summary="场地价格规则表-编辑")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppSitePriceRules appSitePriceRules) {
		appSitePriceRulesService.updateById(appSitePriceRules);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-通过id删除")
	@Operation(summary="场地价格规则表-通过id删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appSitePriceRulesService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-批量删除")
	@Operation(summary="场地价格规则表-批量删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.appSitePriceRulesService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "场地价格规则表-通过id查询")
	@Operation(summary="场地价格规则表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppSitePriceRules> queryById(@RequestParam(name="id",required=true) String id) {
		AppSitePriceRules appSitePriceRules = appSitePriceRulesService.getById(id);
		if(appSitePriceRules==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(appSitePriceRules);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appSitePriceRules
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppSitePriceRules appSitePriceRules) {
        return super.exportXls(request, appSitePriceRules, AppSitePriceRules.class, "场地价格规则表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site_price_rules:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppSitePriceRules.class);
    }

}
