package org.jeecg.modules.system.app.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.JsonNode;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @Description: 门店信息拓展表
 * @Author: jeecg-boot
 * @Date:   2025-07-09
 * @Version: V1.0
 */
@Data
@TableName("nm_site")
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@Schema(description="门店信息拓展表")
public class AppSite implements Serializable {
    private static final long serialVersionUID = 1L;

	/**id*/
	@TableId(type = IdType.ASSIGN_ID)
    @Schema(description = "id")
    private String id;
	/**部门编码*/
	@Excel(name = "部门编码", width = 15)
    @Schema(description = "部门编码")
    private String orgCode;
	/**关联部门id*/
	@Excel(name = "关联部门id", width = 15)
    @Schema(description = "关联部门id")
    private String tenantId;
	/**名称*/
	@Excel(name = "名称", width = 15)
    @Schema(description = "名称")
    private String name;
	/**省*/
	@Excel(name = "省", width = 15)
    @Schema(description = "省")
    private String province;
	/**市*/
	@Excel(name = "市", width = 15)
    @Schema(description = "市")
    private String city;
	/**区县*/
	@Excel(name = "区县", width = 15)
    @Schema(description = "区县")
    private String area;
	/**地址*/
	@Excel(name = "地址", width = 15)
    @Schema(description = "地址")
    private String address;
	/**0学校 1体育馆*/
	@Excel(name = "0学校 1体育馆", width = 15)
    @Schema(description = "0学校 1体育馆")
    private Integer type;
	/**经营状态0营业 1休息*/
	@Excel(name = "经营状态0营业 1休息", width = 15)
    @Schema(description = "经营状态0营业 1休息")
    private Integer runStatus;
	/**经营类型0全天 1自定义*/
	@Excel(name = "经营类型0全天 1自定义", width = 15)
    @Schema(description = "经营类型0全天 1自定义")
    private Integer runType;
    /**开始营业时间 时间为空则全天*/
    @Excel(name = "开始营业时间", width = 20, format = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "开始营业时间")
    private Date startTime;
    /**结束营业时间*/
    @Excel(name = "结束营业时间", width = 20, format = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "结束营业时间")
    private Date endTime;
	/**客服电话*/
	@Excel(name = "客服电话", width = 15)
    @Schema(description = "客服电话")
    private String phone;
	/**运动类目id;多个用逗号分割*/
	@Excel(name = "运动类目id;多个用逗号分割", width = 15)
    @Schema(description = "运动类目id;多个用逗号分割")
    private String categoryId;
	/**信息/设施*/
	@Excel(name = "信息/设施", width = 15)
    @Schema(description = "信息/设施")
    private String facility;
	/**图片*/
	@Excel(name = "图片", width = 15)
    @Schema(description = "图片")
    private String cover;
	/**视频*/
	@Excel(name = "视频", width = 15)
    @Schema(description = "视频")
    private String video;
	/**好评率*/
	@Excel(name = "好评率", width = 15)
    @Schema(description = "好评率")
    private BigDecimal goodRate;
	/**纬度*/
	@Excel(name = "纬度", width = 15)
    @Schema(description = "纬度")
    private BigDecimal latitude;
	/**经度*/
	@Excel(name = "经度", width = 15)
    @Schema(description = "经度")
    private BigDecimal longitude;
	/**排序*/
	@Excel(name = "排序", width = 15)
    @Schema(description = "排序")
    private Integer sort;
	/**vr图JSON数据*/
	@Excel(name = "vr图JSON数据", width = 15)
    @Schema(description = "vr图JSON数据")
    private String vr;
	/**系统状态;状态（0-正常,1-冻结）*/
	@Excel(name = "系统状态;状态（0-正常,1-冻结）", width = 15)
    @Schema(description = "系统状态;状态（0-正常,1-冻结）")
    private Integer status;
	/**删除标志;删除状态(0-正常,1-已删除)*/
	@Excel(name = "删除标志;删除状态(0-正常,1-已删除)", width = 15)
    @Schema(description = "删除标志;删除状态(0-正常,1-已删除)")
    @TableLogic
    private Integer delFlag;
	/**乐观锁*/
	@Excel(name = "乐观锁", width = 15)
    @Schema(description = "乐观锁")
    private Integer revision;
	/**创建人;创建人*/
    @Schema(description = "创建人;创建人")
    private String createBy;
	/**创建时间;创建时间*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间;创建时间")
    private Date createTime;
	/**更新人;更新人*/
    @Schema(description = "更新人;更新人")
    private String updateBy;
	/**更新时间;更新时间*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间;更新时间")
    private Date updateTime;
    /**非教学日*/
    @Excel(name = "非教学日", width = 15)
    @Schema(description = "非教学日")
    private JsonNode noTeachingDay;
    /**教学日*/
    @Excel(name = "教学日", width = 15)
    @Schema(description = "教学日")
    private JsonNode teachingDay;
}
