package org.jeecg.modules.system.app.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @Description: 场地价格规则表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Data
@TableName("nm_site_price_rules")
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@Schema(description="场地价格规则表")
public class AppSitePriceRules implements Serializable {
    private static final long serialVersionUID = 1L;

    /**id*/
    @TableId(type = IdType.ASSIGN_ID)
    @Schema(description = "id")
    private String id;
    /**部门编码*/
    @Excel(name = "部门编码", width = 15)
    @Schema(description = "部门编码")
    private String orgCode;
    /**关联编码id*/
    @Excel(name = "关联编码id", width = 15)
    @Schema(description = "关联编码id")
    private String tenantId;
    /**场所*/
    @Excel(name = "场所", width = 15)
    @Schema(description = "场所")
    private String sitePlaceId;
    /**运动类型*/
    @Excel(name = "运动类型", width = 15)
    @Schema(description = "运动类型")
    private String categoryId;
    /**0学校 1体育馆包场 2体育馆不固定场*/
    @Excel(name = "0学校 1体育馆包场 2体育馆不固定场", width = 15)
    @Schema(description = "0学校 1体育馆包场 2体育馆不固定场")
    private Integer type;
    /**开始时间*/
    @Excel(name = "开始时间", width = 20, format = "HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "HH:mm:ss")
    @DateTimeFormat(pattern="HH:mm:ss")
    @Schema(description = "开始时间")
    private Date startTime;
    /**结束时间*/
    @Excel(name = "结束时间", width = 20, format = "HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "HH:mm:ss")
    @DateTimeFormat(pattern="HH:mm:ss")
    @Schema(description = "结束时间")
    private Date endTime;
    /**星期几*/
    @Excel(name = "星期几", width = 15)
    @Schema(description = "星期几")
    private String dayOfWeek;
    /**原价*/
    @Excel(name = "原价", width = 15)
    @Schema(description = "原价")
    private BigDecimal originalPrice;
    /**售价*/
    @Excel(name = "售价", width = 15)
    @Schema(description = "售价")
    private BigDecimal sellingPrice;
    /**是否教学日0是1不是*/
    @Excel(name = "是否教学日0是1不是", width = 15)
    @Schema(description = "是否教学日0是1不是")
    private Integer isTeaching;
    /**展示状态(0正常，1已定，2过期)*/
    @Excel(name = "展示状态(0正常，1已定，2过期)", width = 15)
    @Schema(description = "展示状态(0正常，1已定，2过期)")
    private Integer viewStatus;

    /**乐观锁*/
    @Excel(name = "乐观锁", width = 15)
    @Schema(description = "乐观锁")
    private Integer revision;
    /**创建人;创建人*/
    @Schema(description = "创建人;创建人")
    private String createBy;
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern="yyyy-MM-dd")
    @Schema(description = "销售日期")
    private Date dateOfSale;
    /**创建时间;创建时间*/
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间;创建时间")
    private Date createTime;
    /**更新人;更新人*/
    @Schema(description = "更新人;更新人")
    private String updateBy;
    /**更新时间;更新时间*/
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间;更新时间")
    private Date updateTime;
    /**系统状态;状态(0-正常,1-冻结)*/
    @Excel(name = "系统状态;状态(0-正常,1-冻结)", width = 15)
    @Schema(description = "系统状态;状态(0-正常,1-冻结)")
    private Integer status;
    /**删除标志;删除状态(0-正常,1-已删除)*/
    @Excel(name = "删除标志;删除状态(0-正常,1-已删除)", width = 15)
    @Schema(description = "删除标志;删除状态(0-正常,1-已删除)")
    @TableLogic
    private Integer delFlag;
    /**场数*/
    @Schema(description = "场数/库存")
    private Integer inventory;
}
