package org.jeecg.modules.system.app.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.dom4j.rule.RuleManager;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.system.app.dto.AppCoursesCuDTO;
import org.jeecg.modules.system.app.dto.AppCoursesDTO;
import org.jeecg.modules.system.app.dto.AppCoursesPageDTO;
import org.jeecg.modules.system.app.dto.AppCoursesRuleDTO;
import org.jeecg.modules.system.app.entity.AppCourses;
import org.jeecg.modules.system.app.entity.AppCoursesPriceRules;
import org.jeecg.modules.system.app.entity.AppSite;
import org.jeecg.modules.system.app.mapper.AppCoursesMapper;
import org.jeecg.modules.system.app.mapper.AppCoursesPriceRulesMapper;
import org.jeecg.modules.system.app.mapper.AppSiteMapper;
import org.jeecg.modules.system.app.service.IAppCoureseService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

import static org.jeecg.common.constant.CommonConstant.SC_INTERNAL_SERVER_ERROR_500;

/**
 * @Description: 课程/培训表
 * @Author: jeecg-boot
 * @Date: 2025-07-03
 * @Version: V1.0
 */
@Service
public class AppCoureseServiceImpl extends ServiceImpl<AppCoursesMapper, AppCourses> implements IAppCoureseService {
    @Resource
    private AppCoursesPriceRulesMapper priceRulesMapper;
    @Resource
    private AppSiteMapper siteMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean saveWitchPriceRules(AppCoursesDTO appCoursesDTO) {
        AppCoursesCuDTO coursesCuDTO = appCoursesDTO.getCourses();
        if (null == coursesCuDTO.getCategoryId()) throw new JeecgBootException("请选择课程类别");
        AppSite site = siteMapper.selectById(coursesCuDTO.getSiteId());
        AppCourses appCourses = new AppCourses();
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        BeanUtils.copyProperties(coursesCuDTO, appCourses);
        appCourses.setOrgCode(site.getOrgCode());
        appCourses.setTenantId(site.getTenantId());
        appCourses.setUserId(loginUser.getId());
        List<AppCoursesRuleDTO> coursesRuleDTOS= appCoursesDTO.getPriceRulesList();
        //起止时间计算
        Optional<Date> minStartTime = coursesRuleDTOS.stream()
                .map(AppCoursesRuleDTO::getStartTime)
                .filter(Objects::nonNull)
                .min(Date::compareTo);

        Optional<Date> maxEndTime = coursesRuleDTOS.stream()
                .map(AppCoursesRuleDTO::getEndTime)
                .filter(Objects::nonNull)
                .max(Date::compareTo);
        appCourses.setStartTime(minStartTime.orElse(null));
        appCourses.setEndTime(maxEndTime.orElse(null));
        int saveCourseResult = baseMapper.insert(appCourses);
        if (saveCourseResult < 1) {
            throw new JeecgBootException("课程信息保存失败");
        }
        for (AppCoursesRuleDTO rule : coursesRuleDTOS) {
            AppCoursesPriceRules appCoursesPriceRules = new AppCoursesPriceRules();
            BeanUtils.copyProperties(rule, appCoursesPriceRules);
            appCoursesPriceRules.setCoursesId(appCourses.getId());
            appCoursesPriceRules.setOrgCode(appCourses.getOrgCode());
            appCoursesPriceRules.setTenantId(appCourses.getTenantId());
            int savePriceResult = priceRulesMapper.insert(appCoursesPriceRules); // 保证每个操作都在事务中
            if (savePriceResult < 1) {
                throw new JeecgBootException("课程价格规则保存失败");
            }
        }
        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean editWitchPriceRules(AppCoursesCuDTO coursesCuDTO) {
        if (null == coursesCuDTO.getCategoryId()) throw new JeecgBootException("请选择课程类别");
        AppSite site = siteMapper.selectById(coursesCuDTO.getSiteId());
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        AppCourses dbCourse = baseMapper.selectById(coursesCuDTO.getId());
//        checkPermission(loginUser, dbCourse);
        AppCourses course = new AppCourses();
        BeanUtils.copyProperties(coursesCuDTO, course);
        course.setOrgCode(site.getOrgCode());
        course.setTenantId(site.getTenantId());
        course.setUserId(loginUser.getId());
        int updateCourseResult = baseMapper.updateById(course);
        if (updateCourseResult < 1) {
            throw new JeecgBootException("课程信息保存失败");
        }
        return Boolean.TRUE;
    }

    @Override
    public AppCoursesDTO queryWitchPriceRulesById(String id) {
        AppCourses dbCourse = baseMapper.selectById(id);
        if (null==dbCourse) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(sysUser,dbCourse);
        List<AppCoursesPriceRules> priceRulesList =
                priceRulesMapper.selectList(Wrappers.<AppCoursesPriceRules>lambdaQuery().eq(AppCoursesPriceRules::getCoursesId, id));
        AppCoursesCuDTO coursesCuDTO = new AppCoursesCuDTO();
        BeanUtils.copyProperties(dbCourse, coursesCuDTO);
        List<AppCoursesRuleDTO> priceRules =new ArrayList<>();
        priceRulesList.forEach(rule-> {
            AppCoursesRuleDTO appCoursesRuleDTO = new AppCoursesRuleDTO();
            BeanUtils.copyProperties(rule, appCoursesRuleDTO);
            priceRules.add(appCoursesRuleDTO);
        });

        return new AppCoursesDTO(coursesCuDTO, priceRules);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean deleteWitchPriceRulesById(String id) {
        AppCourses dbCourse = baseMapper.selectById(id);
        if (null==dbCourse) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(sysUser,dbCourse);
        int deleteCourseResult = baseMapper.deleteById(id);
        if (deleteCourseResult < 1) {
            throw new JeecgBootException("课程信息删除失败", SC_INTERNAL_SERVER_ERROR_500);
        }
        int deletePriceResult = priceRulesMapper.delete(Wrappers.<AppCoursesPriceRules>lambdaQuery().eq(AppCoursesPriceRules::getCoursesId, id));
        if (deletePriceResult<1) throw new JeecgBootException("课程价格规则删除失败", SC_INTERNAL_SERVER_ERROR_500);
        return Boolean.TRUE;
    }

    @Override
    public IPage<AppCoursesCuDTO> queryWitchPriceRulesPage(AppCoursesPageDTO dto) {
        Page<AppCourses> page = new Page<>(dto.getPageNum(), dto.getPageSize());
        LambdaQueryWrapper<AppCourses> wrapper = Wrappers.<AppCourses>lambdaQuery()
                .like(StringUtils.isNotBlank(dto.getName()), AppCourses::getName, dto.getName());
//                .eq(AppCourses::getOrgCode, loginUser.getOrgCode());
        IPage<AppCourses> resultPage = baseMapper.selectPage(page, wrapper);
        return resultPage.convert(record -> {
            AppCoursesCuDTO cuDTO = new AppCoursesCuDTO();
            BeanUtils.copyProperties(record,cuDTO);
            Long l = priceRulesMapper.selectCount(Wrappers.<AppCoursesPriceRules>lambdaQuery().eq(AppCoursesPriceRules::getCoursesId, record.getId()));
            cuDTO.setTotalNum(l.intValue());
            return cuDTO;
        });
    }

    /**
     *  校验权限
     * @param loginUser
     * @param course
     */
    private void checkPermission(LoginUser loginUser, AppCourses course) {
        if (!loginUser.getOrgCode().equals(course.getOrgCode())) throw new JeecgBootException("无权限操作", SC_INTERNAL_SERVER_ERROR_500);
    }
}
