package org.jeecg.modules.system.app.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.system.app.dto.*;
import org.jeecg.modules.system.app.entity.AppSite;
import org.jeecg.modules.system.app.mapper.AppSiteMapper;
import org.jeecg.modules.system.app.mapper.AppSitePriceRulesMapper;
import org.jeecg.modules.system.app.service.IAppSiteService;
import org.jeecg.modules.system.app.vo.AppSiteListVO;
import org.jeecg.modules.system.entity.SysDepart;
import org.jeecg.modules.system.mapper.SysDepartMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

import java.util.List;
import java.util.stream.Collectors;

import static org.jeecg.common.constant.CommonConstant.SC_INTERNAL_SERVER_ERROR_500;

/**
 * @Description: 场地表
 * @Author: jeecg-boot
 * @Date: 2025-07-03
 * @Version: V1.0
 */
@Service
public class AppSiteServiceImpl extends ServiceImpl<AppSiteMapper, AppSite> implements IAppSiteService {
    @Resource
    private AppSitePriceRulesMapper priceRulesMapper;
    @Resource
    private SysDepartMapper sysDepartMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean saveSite(AppSiteDTO siteCuDTO) {
        if (null == siteCuDTO.getType()) throw new JeecgBootException("商户类型不能为空", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        AppSite site = new AppSite();
        SysDepart departById = sysDepartMapper.getDepartById(siteCuDTO.getTenantId());
        if (null == departById) throw new JeecgBootException("商户部门不存在", SC_INTERNAL_SERVER_ERROR_500);
        if (!departById.getOrgType().equals("3")) throw new JeecgBootException("商户部门类型错误", SC_INTERNAL_SERVER_ERROR_500);
        BeanUtils.copyProperties(siteCuDTO, site);
        if (null == site.getOrgCode())
            throw new JeecgBootException("商户部门编码不能为空", SC_INTERNAL_SERVER_ERROR_500);
        if (null == site.getTenantId())
            throw new JeecgBootException("商户部门id不能为空", SC_INTERNAL_SERVER_ERROR_500);
        int saveSiteResult = baseMapper.insert(site);
        // 如果插入失败，抛出自定义异常提示“场地信息保存失败”
        if (saveSiteResult < 1) {
            throw new JeecgBootException("商户信息保存失败", SC_INTERNAL_SERVER_ERROR_500);
        }
        departById.setAddress(site.getProvince()+site.getCity()+site.getArea()+site.getAddress());
        int updateById = sysDepartMapper.updateById(departById);
        if (updateById < 1) {
            throw new JeecgBootException("商户部门信息更新失败");
        }
        // 所有操作成功完成后返回 true
        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean editSite(AppSiteDTO siteCuDTO) {
        AppSite site = new AppSite();
        BeanUtils.copyProperties(siteCuDTO, site);
        if (null == site.getType()) throw new JeecgBootException("场地类型不能为空", SC_INTERNAL_SERVER_ERROR_500);
        AppSite dbSite = baseMapper.selectById(site.getId());
        if (null == dbSite) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(dbSite,sysUser);
        if (null == site.getOrgCode())
            throw new JeecgBootException("商户部门编码不能为空", SC_INTERNAL_SERVER_ERROR_500);
        if (null == site.getTenantId())
            throw new JeecgBootException("商户部门id不能为空", SC_INTERNAL_SERVER_ERROR_500);
        int updateSiteResult = baseMapper.updateById(site);
        if (updateSiteResult < 1) {
            throw new JeecgBootException("商户信息保存失败", SC_INTERNAL_SERVER_ERROR_500);
        }
        return Boolean.TRUE;
    }

    @Override
    public AppSiteDTO querySiteById(String id) {
        AppSite dbSite = baseMapper.selectById(id);
        if (null == dbSite) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        AppSiteDTO appSiteDTO = new AppSiteDTO();
        BeanUtils.copyProperties(dbSite, appSiteDTO);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(dbSite,sysUser);
        return appSiteDTO;
    }

    @Override
    public List<AppSiteListVO> querySiteListByOrgCode(String orgCode) {
        List<AppSite> siteList = baseMapper.selectList(Wrappers.<AppSite>lambdaQuery().eq(AppSite::getOrgCode, orgCode));
        return siteList.stream().map(dbSite -> {
            AppSiteListVO siteVO = new AppSiteListVO();
            BeanUtils.copyProperties(dbSite, siteVO);
            return siteVO;
        }).collect(Collectors.toList());
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean deleteSiteById(String id) {
        AppSite dbSite = baseMapper.selectById(id);
        if (null == dbSite) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(dbSite,sysUser);
        int deleteSiteResult = baseMapper.deleteById(id);
        if (deleteSiteResult < 1) {
            throw new JeecgBootException("商户信息删除失败", SC_INTERNAL_SERVER_ERROR_500);
        }
        return Boolean.TRUE;
    }

    @Override
    public IPage<AppSiteDTO> querySitePage(AppSitePageDTO dto) {
        Page<AppSite> page = new Page<>(dto.getPageNum(), dto.getPageSize());
        LambdaQueryWrapper<AppSite> wrapper = Wrappers.<AppSite>lambdaQuery()
                .like(StringUtils.isNotBlank(dto.getName()), AppSite::getName, dto.getName());
        IPage<AppSite> resultPage = baseMapper.selectPage(page, wrapper);

        return resultPage.convert(record -> {
            AppSiteDTO cuDTO = new AppSiteDTO();
            BeanUtils.copyProperties(record, cuDTO);
            return cuDTO;
        });
    }

    /**
     * 权限校验
     *
     * @param site
     * @param sysUser
     */
    private void checkPermission(AppSite site, LoginUser sysUser) {
        if (!sysUser.getOrgCode().equals(site.getOrgCode()))
            throw new JeecgBootException("无权限操作", SC_INTERNAL_SERVER_ERROR_500);
    }
}
